@@ -1,5 +1,5 @@
 var a00812 =
 [
     [ "Tessellation", "a00961.html", "a00961" ],
-    [ "Tessellation::Options", "a00965.html", "a00965" ]
+    [ "Options", "a00965.html", "a00965" ]
 ];
\ No newline at end of file
