@@ -1,5 +1,5 @@
 var a00815 =
 [
     [ "SurfaceFactory", "a00941.html", "a00941" ],
-    [ "SurfaceFactory::Options", "a00945.html", "a00945" ]
+    [ "Options", "a00945.html", "a00945" ]
 ];
\ No newline at end of file
