@@ -1,5 +1,5 @@
 var a00818 =
 [
     [ "Surface< REAL >", "a00933.html", "a00933" ],
-    [ "Surface< REAL >::PointDescriptor", "a00937.html", "a00937" ]
+    [ "PointDescriptor", "a00937.html", "a00937" ]
 ];
\ No newline at end of file
