@@ -1,5 +1,5 @@
 var a00851 =
 [
     [ "PatchTable", "a00993.html", "a00993" ],
-    [ "PatchTable::PatchHandle", "a00997.html", "a00997" ]
+    [ "PatchHandle", "a00997.html", "a00997" ]
 ];
\ No newline at end of file
